@@ -6,11 +6,10 @@ use warnings;
 no warnings qw(recursion);
 use Carp;
 use Data::Dumper;
-use Scalar::Util qw(blessed);
 use UNIVERSAL::DOES;
 
 BEGIN {
-  our $VERSION = '2.25'; # version template
+  our $VERSION = '2.26'; # version template
 }
 use List::Util qw(first);
 use Treex::PML::Instance::Common qw(:diagnostics :constants);
@@ -616,10 +615,10 @@ sub compile_schema {
           } else {
             $href = $references->{$id};
           }
-          if (ref $href) {
-              $href = Treex::PML::IO::make_relative_URI($href,$filename);
-          } else { # Coming from resources.
+          if (ref $href && $href->isa('Treex::PML::Resource::URI')) {
               $href = Treex::PML::IO::make_relative_URI($href,$href);
+          } else {
+              $href = Treex::PML::IO::make_relative_URI($href,$filename);
           }
           my $name = $names{$id};
           for ($id,$href, (defined $name ? $name : ())) { s/&/&amp;/g;  s/</&lt;/g;  s/"/&quot;/g; }
